@@ -5,7 +5,11 @@ from wagtail.admin.rich_text.converters.html_to_contentstate import (
 )
 import wagtail.admin.rich_text.editors.draftail.features as draftail_features
 from wagtail.admin.rich_text.converters.html_to_contentstate import InlineStyleElementHandler
+from django.urls import include, path, reverse
+from django.utils.translation import gettext_lazy as _
+from wagtail.admin.menu import MenuItem
 from wagtail.core import hooks
+from webspace.cms.bakery import urls as urls_bakery
 
 NOTHING_RE = re.compile('a^')
 
@@ -78,3 +82,36 @@ def register_code_block_feature(features):
         },
     })
     features.default_features.append(feature_name)
+
+
+#  Bakery
+
+
+class BakeryItem(MenuItem):
+    """
+    Registers wagtail-cache in wagtail admin for superusers.
+    """
+
+    def is_shown(self, request):
+        return request.user.is_superuser
+
+
+@hooks.register('register_admin_urls')
+def register_admin_urls():
+    """
+    Registers wagtail-cache urls in the wagtail admin.
+    """
+    return [
+        path('bakery/', include((urls_bakery, 'bakery'), namespace='bakery')),
+    ]
+
+
+@hooks.register('register_settings_menu_item')
+def register_cache_menu():
+    """
+    Registers wagtail-cache settings panel in the wagtail admin.
+    """
+    return BakeryItem(
+        _('Bakery'),
+        reverse('bakery:index'),
+        classnames='icon icon-cog')
